@@ -1,4 +1,3 @@
-import django
 from django.contrib import admin
 
 from . import app_settings
@@ -12,11 +11,6 @@ class EmailAddressAdmin(admin.ModelAdmin):
     search_fields = []
     raw_id_fields = ('user',)
 
-    def __init__(self, *args, **kwargs):
-        super(EmailAddressAdmin, self).__init__(*args, **kwargs)
-        if not self.search_fields and django.VERSION[:2] < (1, 7):
-            self.search_fields = self.get_search_fields(None)
-
     def get_search_fields(self, request):
         base_fields = get_adapter(request).get_user_search_fields()
         return ['email'] + list(map(lambda a: 'user__' + a, base_fields))
