@@ -1,5 +1,7 @@
+from django.contrib.auth.signals import user_logged_out  # noqa
 from django.dispatch import Signal
 
+
 user_logged_in = Signal(providing_args=["request", "user"])
 
 # Typically followed by `user_logged_in` (unless, e-mail verification kicks in)
@@ -9,10 +11,13 @@ password_set = Signal(providing_args=["request", "user"])
 password_changed = Signal(providing_args=["request", "user"])
 password_reset = Signal(providing_args=["request", "user"])
 
-email_confirmed = Signal(providing_args=["email_address"])
-email_confirmation_sent = Signal(providing_args=["confirmation"])
+email_confirmed = Signal(providing_args=["request", "email_address"])
+email_confirmation_sent = Signal(
+    providing_args=["request", "confirmation", "signup"])
 
-email_changed = Signal(providing_args=["request", "user",
-                            "from_email_address", "to_email_address"])
+email_changed = Signal(
+    providing_args=[
+        "request", "user",
+        "from_email_address", "to_email_address"])
 email_added = Signal(providing_args=["request", "user", "email_address"])
 email_removed = Signal(providing_args=["request", "user", "email_address"])
