@@ -1,10 +1,9 @@
-from django.conf.urls import patterns, url
-from django.views.generic import RedirectView
+from django.conf.urls import url
 
 from . import views
 
-urlpatterns = patterns(
-    "",
+
+urlpatterns = [
     url(r"^signup/$", views.signup, name="account_signup"),
     url(r"^login/$", views.login, name="account_login"),
     url(r"^logout/$", views.logout, name="account_logout"),
@@ -19,7 +18,7 @@ urlpatterns = patterns(
     url(r"^email/$", views.email, name="account_email"),
     url(r"^confirm-email/$", views.email_verification_sent,
         name="account_email_verification_sent"),
-    url(r"^confirm-email/(?P<key>\w+)/$", views.confirm_email,
+    url(r"^confirm-email/(?P<key>[-:\w]+)/$", views.confirm_email,
         name="account_confirm_email"),
 
     # password reset
@@ -32,4 +31,4 @@ urlpatterns = patterns(
         name="account_reset_password_from_key"),
     url(r"^password/reset/key/done/$", views.password_reset_from_key_done,
         name="account_reset_password_from_key_done"),
-)
+]
