@@ -1,39 +1,30 @@
+from collections import OrderedDict
 from datetime import timedelta
-try:
-    from django.utils.timezone import now
-except ImportError:
-    from datetime import datetime
-    now = datetime.now
 
-import django
-from django.contrib import messages
-from django.core.urlresolvers import reverse
 from django.conf import settings
+from django.contrib import messages
+from django.contrib.auth import update_session_auth_hash
+from django.core.exceptions import FieldDoesNotExist, ValidationError
+from django.db import models
+from django.db.models import Q
 from django.http import HttpResponseRedirect
 from django.utils import six
+from django.utils.encoding import force_text
 from django.utils.http import urlencode
-from django.utils.http import int_to_base36, base36_to_int
-from django.core.exceptions import ValidationError
+from django.utils.timezone import now
 
-if django.VERSION > (1, 8,):
-    from collections import OrderedDict
-else:
-    from django.utils.datastructures import SortedDict as OrderedDict
-
-try:
-    from django.utils.encoding import force_text
-except ImportError:
-    from django.utils.encoding import force_unicode as force_text
+from allauth.compat import base36_to_int, int_to_base36
 
+from . import app_settings, signals
 from ..exceptions import ImmediateHttpResponse
-from ..utils import (import_callable, valid_email_or_none,
-                     get_user_model, get_request_param)
-
-from . import signals
-
-from .app_settings import EmailVerificationMethod
-from . import app_settings
+from ..utils import (
+    get_request_param,
+    get_user_model,
+    import_callable,
+    valid_email_or_none,
+)
 from .adapter import get_adapter
+from .app_settings import EmailVerificationMethod
 
 
 def get_next_redirect_url(request, redirect_field_name="next"):
@@ -42,22 +33,36 @@ def get_next_redirect_url(request, redirect_field_name="next"):
     via the request.
     """
     redirect_to = get_request_param(request, redirect_field_name)
-    if not get_adapter().is_safe_url(redirect_to):
+    if not get_adapter(request).is_safe_url(redirect_to):
         redirect_to = None
     return redirect_to
 
 
 def get_login_redirect_url(request, url=None, redirect_field_name="next"):
-    redirect_url \
-        = (url
-           or get_next_redirect_url(request,
-                                    redirect_field_name=redirect_field_name)
-           or get_adapter().get_login_redirect_url(request))
+    if url and callable(url):
+        # In order to be able to pass url getters around that depend
+        # on e.g. the authenticated state.
+        url = url()
+    redirect_url = (
+        url or
+        get_next_redirect_url(
+            request,
+            redirect_field_name=redirect_field_name) or
+        get_adapter(request).get_login_redirect_url(request))
     return redirect_url
 
+
 _user_display_callable = None
 
 
+def logout_on_password_change(request, user):
+    # Since it is the default behavior of Django to invalidate all sessions on
+    # password change, this function actually has to preserve the session when
+    # logout isn't desired.
+    if not app_settings.LOGOUT_ON_PASSWORD_CHANGE:
+        update_session_auth_hash(request, user)
+
+
 def default_user_display(user):
     if app_settings.USER_MODEL_USERNAME_FIELD:
         return getattr(user, app_settings.USER_MODEL_USERNAME_FIELD)
@@ -78,20 +83,30 @@ def user_field(user, field, *args):
     """
     Gets or sets (optional) user model fields. No-op if fields do not exist.
     """
-    if field and hasattr(user, field):
-        if args:
-            # Setter
-            v = args[0]
-            if v:
-                User = get_user_model()
-                v = v[0:User._meta.get_field(field).max_length]
-            setattr(user, field, v)
-        else:
-            # Getter
-            return getattr(user, field)
+    if not field:
+        return
+    User = get_user_model()
+    try:
+        field_meta = User._meta.get_field(field)
+        max_length = field_meta.max_length
+    except FieldDoesNotExist:
+        if not hasattr(user, field):
+            return
+        max_length = None
+    if args:
+        # Setter
+        v = args[0]
+        if v:
+            v = v[0:max_length]
+        setattr(user, field, v)
+    else:
+        # Getter
+        return getattr(user, field)
 
 
 def user_username(user, *args):
+    if args and not app_settings.PRESERVE_USERNAME_CASING and args[0]:
+        args = [args[0].lower()]
     return user_field(user, app_settings.USER_MODEL_USERNAME_FIELD, *args)
 
 
@@ -113,8 +128,9 @@ def perform_login(request, user, email_verification,
     # is_active, yet, adapter methods could toy with is_active in a
     # `user_signed_up` signal. Furthermore, social users should be
     # stopped anyway.
+    adapter = get_adapter(request)
     if not user.is_active:
-        return HttpResponseRedirect(reverse('account_inactive'))
+        return adapter.respond_user_inactive(request, user)
 
     from .models import EmailAddress
     has_verified_email = EmailAddress.objects.filter(user=user,
@@ -128,10 +144,10 @@ def perform_login(request, user, email_verification,
     elif email_verification == EmailVerificationMethod.MANDATORY:
         if not has_verified_email:
             send_email_confirmation(request, user, signup=signup)
-            return HttpResponseRedirect(
-                reverse('account_email_verification_sent'))
+            return adapter.respond_email_verification_sent(
+                request, user)
     try:
-        get_adapter().login(request, user)
+        adapter.login(request, user)
         response = HttpResponseRedirect(
             get_login_redirect_url(request, redirect_url))
 
@@ -142,10 +158,11 @@ def perform_login(request, user, email_verification,
                                     response=response,
                                     user=user,
                                     **signal_kwargs)
-        get_adapter().add_message(request,
-                                  messages.SUCCESS,
-                                  'account/messages/logged_in.txt',
-                                  {'user': user})
+        adapter.add_message(
+            request,
+            messages.SUCCESS,
+            'account/messages/logged_in.txt',
+            {'user': user})
     except ImmediateHttpResponse as e:
         response = e.response
     return response
@@ -175,7 +192,7 @@ def cleanup_email_addresses(request, addresses):
     exist, the first one encountered will be kept as primary.
     """
     from .models import EmailAddress
-    adapter = get_adapter()
+    adapter = get_adapter(request)
     # Let's group by `email`
     e2a = OrderedDict()  # maps email to EmailAddress
     primary_addresses = []
@@ -187,10 +204,8 @@ def cleanup_email_addresses(request, addresses):
         if not email:
             continue
         # ... and non-conflicting ones...
-        if (app_settings.UNIQUE_EMAIL
-                and EmailAddress.objects
-                .filter(email__iexact=email)
-                .exists()):
+        if (app_settings.UNIQUE_EMAIL and
+                EmailAddress.objects.filter(email__iexact=email).exists()):
             continue
         a = e2a.get(email.lower())
         if a:
@@ -236,10 +251,10 @@ def setup_user_email(request, user, addresses):
     """
     from .models import EmailAddress
 
-    assert EmailAddress.objects.filter(user=user).count() == 0
+    assert not EmailAddress.objects.filter(user=user).exists()
     priority_addresses = []
     # Is there a stashed e-mail?
-    adapter = get_adapter()
+    adapter = get_adapter(request)
     stashed_email = adapter.unstash_verified_email(request)
     if stashed_email:
         priority_addresses.append(EmailAddress(user=user,
@@ -252,16 +267,14 @@ def setup_user_email(request, user, addresses):
                                                email=email,
                                                primary=True,
                                                verified=False))
-    addresses, primary = cleanup_email_addresses(request,
-                                                 priority_addresses
-                                                 + addresses)
+    addresses, primary = cleanup_email_addresses(
+        request,
+        priority_addresses + addresses)
     for a in addresses:
         a.user = user
         a.save()
     EmailAddress.objects.fill_cache_for_user(user, addresses)
-    if (primary
-            and email
-            and email.lower() != primary.email.lower()):
+    if (primary and email and email.lower() != primary.email.lower()):
         user_email(user, primary.email)
         user.save()
     return primary
@@ -276,20 +289,26 @@ def send_email_confirmation(request, user, signup=False):
 
     Especially in case of b), we want to limit the number of mails
     sent (consider a user retrying a few times), which is why there is
-    a cooldown period before sending a new mail.
+    a cooldown period before sending a new mail. This cooldown period
+    can be configured in ACCOUNT_EMAIL_CONFIRMATION_COOLDOWN setting.
     """
     from .models import EmailAddress, EmailConfirmation
 
-    COOLDOWN_PERIOD = timedelta(minutes=3)
+    cooldown_period = timedelta(
+        seconds=app_settings.EMAIL_CONFIRMATION_COOLDOWN
+    )
+
     email = user_email(user)
     if email:
         try:
             email_address = EmailAddress.objects.get_for_user(user, email)
             if not email_address.verified:
-                send_email = not EmailConfirmation.objects \
-                    .filter(sent__gt=now() - COOLDOWN_PERIOD,
-                            email_address=email_address) \
-                    .exists()
+                if app_settings.EMAIL_CONFIRMATION_HMAC:
+                    send_email = True
+                else:
+                    send_email = not EmailConfirmation.objects.filter(
+                        sent__gt=now() - cooldown_period,
+                        email_address=email_address).exists()
                 if send_email:
                     email_address.send_confirmation(request,
                                                     signup=signup)
@@ -305,13 +324,14 @@ def send_email_confirmation(request, user, signup=False):
             assert email_address
         # At this point, if we were supposed to send an email we have sent it.
         if send_email:
-            get_adapter().add_message(request,
-                                      messages.INFO,
-                                      'account/messages/'
-                                      'email_confirmation_sent.txt',
-                                      {'email': email})
+            get_adapter(request).add_message(
+                request,
+                messages.INFO,
+                'account/messages/'
+                'email_confirmation_sent.txt',
+                {'email': email})
     if signup:
-        request.session['account_user'] = user.pk
+        get_adapter(request).stash_user(request, user_pk_to_url_str(user))
 
 
 def sync_user_email_addresses(user):
@@ -336,6 +356,22 @@ def sync_user_email_addresses(user):
                                     verified=False)
 
 
+def filter_users_by_username(*username):
+    if app_settings.PRESERVE_USERNAME_CASING:
+        qlist = [
+            Q(**{app_settings.USER_MODEL_USERNAME_FIELD + '__iexact': u})
+            for u in username]
+        q = qlist[0]
+        for q2 in qlist[1:]:
+            q = q | q2
+        ret = get_user_model().objects.filter(q)
+    else:
+        ret = get_user_model().objects.filter(
+            **{app_settings.USER_MODEL_USERNAME_FIELD + '__in':
+               [u.lower() for u in username]})
+    return ret
+
+
 def filter_users_by_email(email):
     """Return list of users by email address
 
@@ -362,18 +398,33 @@ def passthrough_next_redirect_url(request, url, redirect_field_name):
 
 
 def user_pk_to_url_str(user):
+    """
+    This should return a string.
+    """
+    User = get_user_model()
+    if issubclass(type(User._meta.pk), models.UUIDField):
+        if isinstance(user.pk, six.string_types):
+            return user.pk
+        return user.pk.hex
+
     ret = user.pk
     if isinstance(ret, six.integer_types):
         ret = int_to_base36(user.pk)
-    return ret
+    return str(ret)
 
 
 def url_str_to_user_pk(s):
     User = get_user_model()
     # TODO: Ugh, isn't there a cleaner way to determine whether or not
     # the PK is a str-like field?
+    if getattr(User._meta.pk, 'remote_field', None):
+        pk_field = User._meta.pk.remote_field.to._meta.pk
+    else:
+        pk_field = User._meta.pk
+    if issubclass(type(pk_field), models.UUIDField):
+        return s
     try:
-        User._meta.pk.to_python('a')
+        pk_field.to_python('a')
         pk = s
     except ValidationError:
         pk = base36_to_int(s)
