@@ -1,14 +1,17 @@
-from allauth.socialaccount import providers
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
 
 class BaiduAccount(ProviderAccount):
     def get_profile_url(self):
-        return 'https://openapi.baidu.com/rest/2.0/passport/users/getLoggedInUser'
+        return (
+            'https://openapi.baidu.com'
+            '/rest/2.0/passport/users/getLoggedInUser')
 
     def get_avatar_url(self):
-        return 'http://tb.himg.baidu.com/sys/portraitn/item/' + self.account.extra_data.get('portrait')
+        return (
+            'http://tb.himg.baidu.com/sys/portraitn/item/' +
+            self.account.extra_data.get('portrait'))
 
     def to_str(self):
         dflt = super(BaiduAccount, self).to_str()
@@ -18,7 +21,6 @@ class BaiduAccount(ProviderAccount):
 class BaiduProvider(OAuth2Provider):
     id = 'baidu'
     name = 'Baidu'
-    package = 'allauth.socialaccount.providers.baidu'
     account_class = BaiduAccount
 
     def extract_uid(self, data):
@@ -29,4 +31,4 @@ class BaiduProvider(OAuth2Provider):
                     name=data.get('uname'))
 
 
-providers.registry.register(BaiduProvider)
+provider_classes = [BaiduProvider]
