@@ -1,4 +1,3 @@
-from allauth.socialaccount import providers
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
@@ -18,15 +17,29 @@ class DoubanAccount(ProviderAccount):
 class DoubanProvider(OAuth2Provider):
     id = 'douban'
     name = 'Douban'
-    package = 'allauth.socialaccount.providers.douban'
     account_class = DoubanAccount
 
     def extract_uid(self, data):
         return data['id']
 
     def extract_common_fields(self, data):
-        return dict(username=data.get('id'),
-                    name=data.get('name'))
+        """
+        Extract data from profile json to populate user instance.
+
+        In Douban profile API:
+
+        - id: a digital string, will never change
+        - uid: defaults to id, but can be changed once, used in profile
+          url, like slug
+        - name: display name, can be changed every 30 days
+
+        So we should use `id` as username here, other than `uid`.
+        Also use `name` as `first_name` for displaying purpose.
+        """
+        return {
+            'username': data['id'],
+            'first_name': data.get('name', ''),
+        }
 
 
-providers.registry.register(DoubanProvider)
+provider_classes = [DoubanProvider]
