@@ -1,13 +1,15 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 
 from allauth.socialaccount.providers.oauth2.urls import default_urlpatterns
 
-from .provider import FacebookProvider
 from . import views
+from .provider import FacebookProvider
+
 
 urlpatterns = default_urlpatterns(FacebookProvider)
 
-urlpatterns += patterns('',
-   url('^facebook/login/token/$', views.login_by_token,
-       name="facebook_login_by_token"),
-   )
+urlpatterns += [
+    url(r'^facebook/login/token/$',
+        views.login_by_token,
+        name="facebook_login_by_token"),
+]
