@@ -1,8 +1,19 @@
-from allauth.socialaccount import providers
+from django.conf import settings
+
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
 
+_FXA_SETTINGS = getattr(
+    settings, 'SOCIALACCOUNT_PROVIDERS', {}).get('fxa', {})
+FXA_OAUTH_ENDPOINT = _FXA_SETTINGS.get(
+    'OAUTH_ENDPOINT',
+    'https://oauth.accounts.firefox.com/v1')
+FXA_PROFILE_ENDPOINT = _FXA_SETTINGS.get(
+    'PROFILE_ENDPOINT',
+    'https://profile.accounts.firefox.com/v1')
+
+
 class FirefoxAccountsAccount(ProviderAccount):
 
     def to_str(self):
@@ -12,7 +23,6 @@ class FirefoxAccountsAccount(ProviderAccount):
 class FirefoxAccountsProvider(OAuth2Provider):
     id = 'fxa'
     name = 'Firefox Accounts'
-    package = 'allauth.socialaccount.providers.fxa'
     account_class = FirefoxAccountsAccount
 
     def get_default_scope(self):
@@ -25,4 +35,4 @@ class FirefoxAccountsProvider(OAuth2Provider):
         return dict(email=data.get('email'))
 
 
-providers.registry.register(FirefoxAccountsProvider)
+provider_classes = [FirefoxAccountsProvider]
