@@ -1,4 +1,3 @@
-from allauth.socialaccount import providers
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
@@ -21,7 +20,6 @@ class InstagramAccount(ProviderAccount):
 class InstagramProvider(OAuth2Provider):
     id = 'instagram'
     name = 'Instagram'
-    package = 'allauth.socialaccount.providers.instagram'
     account_class = InstagramAccount
 
     def extract_extra_data(self, data):
@@ -37,4 +35,4 @@ class InstagramProvider(OAuth2Provider):
         return dict(username=data['data'].get('username'))
 
 
-providers.registry.register(InstagramProvider)
+provider_classes = [InstagramProvider]
