@@ -1,10 +1,12 @@
-from allauth.socialaccount.tests import create_oauth2_tests
-from allauth.tests import MockedResponse
-from allauth.socialaccount.providers import registry
+from allauth.socialaccount.tests import OAuth2TestsMixin
+from allauth.tests import MockedResponse, TestCase
 
 from .provider import InstagramProvider
 
-class InstagramTests(create_oauth2_tests(registry.by_id(InstagramProvider.id))):
+
+class InstagramTests(OAuth2TestsMixin, TestCase):
+    provider_id = InstagramProvider.id
+
     def get_mocked_response(self):
         return MockedResponse(200, """
         {
@@ -15,7 +17,8 @@ class InstagramTests(create_oauth2_tests(registry.by_id(InstagramProvider.id))):
             "username": "georgewhewell",
             "bio": "",
             "website": "",
-            "profile_picture": "http://images.ak.instagram.com/profiles/profile_11428116_75sq_1339547159.jpg",
+            "profile_picture":
+            "http://images.ak.instagram.com/profiles/profile_11428116_75sq_1339547159.jpg",
             "full_name": "georgewhewell",
             "counts": {
               "media": 74,
@@ -24,4 +27,4 @@ class InstagramTests(create_oauth2_tests(registry.by_id(InstagramProvider.id))):
             },
             "id": "11428116"
           }
-        }""")
+        }""")  # noqa
