@@ -1,15 +1,14 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
 
-from allauth.socialaccount.tests import create_oauth2_tests
-from allauth.socialaccount.providers import registry
-from allauth.tests import MockedResponse
+from allauth.socialaccount.tests import OAuth2TestsMixin
+from allauth.tests import MockedResponse, TestCase
 
 from .provider import MailRuProvider
 
 
-class MailRuTests(create_oauth2_tests(registry.by_id(MailRuProvider.id))):
+class MailRuTests(OAuth2TestsMixin, TestCase):
+    provider_id = MailRuProvider.id
 
     def get_mocked_response(self, verified_email=True):
         return MockedResponse(200, """
