@@ -1,10 +1,9 @@
-try:
-    from urllib.parse import parse_qsl, urlencode
-except ImportError:
-    from urllib import urlencode
-    from urlparse import parse_qsl
 import requests
 
+from django.utils.http import urlencode
+
+from allauth.compat import parse_qsl
+
 
 class OAuth2Error(Exception):
     pass
@@ -16,15 +15,20 @@ class OAuth2Client(object):
                  access_token_method,
                  access_token_url,
                  callback_url,
-                 scope):
+                 scope,
+                 scope_delimiter=' ',
+                 headers=None,
+                 basic_auth=False):
         self.request = request
         self.access_token_method = access_token_method
         self.access_token_url = access_token_url
         self.callback_url = callback_url
         self.consumer_key = consumer_key
         self.consumer_secret = consumer_secret
-        self.scope = ' '.join(scope)
+        self.scope = scope_delimiter.join(set(scope))
         self.state = None
+        self.headers = headers
+        self.basic_auth = basic_auth
 
     def get_redirect_url(self, authorization_url, extra_params):
         params = {
@@ -39,12 +43,20 @@ class OAuth2Client(object):
         return '%s?%s' % (authorization_url, urlencode(params))
 
     def get_access_token(self, code):
-        data = {'client_id': self.consumer_key,
-                'redirect_uri': self.callback_url,
-                'grant_type': 'authorization_code',
-                'client_secret': self.consumer_secret,
-                'scope': self.scope,
-                'code': code}
+        data = {
+            'redirect_uri': self.callback_url,
+            'grant_type': 'authorization_code',
+            'code': code}
+        if self.basic_auth:
+            auth = requests.auth.HTTPBasicAuth(
+                self.consumer_key,
+                self.consumer_secret)
+        else:
+            auth = None
+            data.update({
+                'client_id': self.consumer_key,
+                'client_secret': self.consumer_secret
+            })
         params = None
         self._strip_empty_keys(data)
         url = self.access_token_url
@@ -52,15 +64,19 @@ class OAuth2Client(object):
             params = data
             data = None
         # TODO: Proper exception handling
-        resp = requests.request(self.access_token_method,
-                                url,
-                                params=params,
-                                data=data)
+        resp = requests.request(
+            self.access_token_method,
+            url,
+            params=params,
+            data=data,
+            headers=self.headers,
+            auth=auth)
+
         access_token = None
         if resp.status_code == 200:
             # Weibo sends json via 'text/plain;charset=UTF-8'
-            if (resp.headers['content-type'].split(';')[0] == 'application/json'
-                or resp.text[:2] == '{"'):
+            if (resp.headers['content-type'].split(
+                    ';')[0] == 'application/json' or resp.text[:2] == '{"'):
                 access_token = resp.json()
             else:
                 access_token = dict(parse_qsl(resp.text))
@@ -70,7 +86,7 @@ class OAuth2Client(object):
         return access_token
 
     def _strip_empty_keys(self, params):
-        """Added because the Dropbox OAuth2 flow doesn't 
+        """Added because the Dropbox OAuth2 flow doesn't
         work when scope is passed in, which is empty.
         """
         keys = [k for k, v in params.items() if v == '']
