@@ -1,33 +1,45 @@
 from __future__ import absolute_import
 
 from datetime import timedelta
+from requests import RequestException
 
 from django.core.exceptions import PermissionDenied
-from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
+from django.urls import reverse
 from django.utils import timezone
 
-from allauth.utils import build_absolute_uri
-from allauth.account import app_settings
-from allauth.socialaccount.helpers import render_authentication_error
+from allauth.exceptions import ImmediateHttpResponse
 from allauth.socialaccount import providers
-from allauth.socialaccount.providers.oauth2.client import (OAuth2Client,
-                                                           OAuth2Error)
-from allauth.socialaccount.helpers import complete_social_login
-from allauth.socialaccount.models import SocialToken, SocialLogin
-from allauth.utils import get_request_param
+from allauth.socialaccount.helpers import (
+    complete_social_login,
+    render_authentication_error,
+)
+from allauth.socialaccount.models import SocialLogin, SocialToken
+from allauth.socialaccount.providers.base import ProviderException
+from allauth.socialaccount.providers.oauth2.client import (
+    OAuth2Client,
+    OAuth2Error,
+)
+from allauth.utils import build_absolute_uri, get_request_param
+
 from ..base import AuthAction, AuthError
 
 
 class OAuth2Adapter(object):
     expires_in_key = 'expires_in'
     supports_state = True
-    redirect_uri_protocol = None  # None: use ACCOUNT_DEFAULT_HTTP_PROTOCOL
+    redirect_uri_protocol = None
     access_token_method = 'POST'
     login_cancelled_error = 'access_denied'
+    scope_delimiter = ' '
+    basic_auth = False
+    headers = None
+
+    def __init__(self, request):
+        self.request = request
 
     def get_provider(self):
-        return providers.registry.by_id(self.provider_id)
+        return providers.registry.by_id(self.provider_id, self.request)
 
     def complete_login(self, request, app, access_token, **kwargs):
         """
@@ -35,6 +47,11 @@ class OAuth2Adapter(object):
         """
         raise NotImplementedError
 
+    def get_callback_url(self, request, app):
+        callback_url = reverse(self.provider_id + "_callback")
+        protocol = self.redirect_uri_protocol
+        return build_absolute_uri(request, callback_url, protocol)
+
     def parse_token(self, data):
         token = SocialToken(token=data['access_token'])
         token.token_secret = data.get('refresh_token', '')
@@ -51,24 +68,25 @@ class OAuth2View(object):
         def view(request, *args, **kwargs):
             self = cls()
             self.request = request
-            self.adapter = adapter()
-            return self.dispatch(request, *args, **kwargs)
+            self.adapter = adapter(request)
+            try:
+                return self.dispatch(request, *args, **kwargs)
+            except ImmediateHttpResponse as e:
+                return e.response
         return view
 
     def get_client(self, request, app):
-        callback_url = reverse(self.adapter.provider_id + "_callback")
-        protocol = (self.adapter.redirect_uri_protocol
-                    or app_settings.DEFAULT_HTTP_PROTOCOL)
-        callback_url = build_absolute_uri(
-            request, callback_url,
-            protocol=protocol)
+        callback_url = self.adapter.get_callback_url(request, app)
         provider = self.adapter.get_provider()
         scope = provider.get_scope(request)
         client = OAuth2Client(self.request, app.client_id, app.secret,
                               self.adapter.access_token_method,
                               self.adapter.access_token_url,
                               callback_url,
-                              scope)
+                              scope,
+                              scope_delimiter=self.adapter.scope_delimiter,
+                              headers=self.adapter.headers,
+                              basic_auth=self.adapter.basic_auth)
         return client
 
 
@@ -123,7 +141,10 @@ class OAuth2CallbackView(OAuth2View):
             else:
                 login.state = SocialLogin.unstash_state(request)
             return complete_social_login(request, login)
-        except (PermissionDenied, OAuth2Error) as e:
+        except (PermissionDenied,
+                OAuth2Error,
+                RequestException,
+                ProviderException) as e:
             return render_authentication_error(
                 request,
                 self.adapter.provider_id,
