@@ -1,14 +1,10 @@
-try:
-    from mock import patch
-except ImportError:
-    from unittest.mock import patch
-
-from django.test import TestCase
 from django.test.utils import override_settings
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 
+from allauth.tests import TestCase, patch
 from allauth.utils import get_user_model
 
+
 SOCIALACCOUNT_PROVIDERS = {'persona':
                            {'AUDIENCE': 'https://www.example.com:433'}}
 
@@ -21,10 +17,11 @@ class PersonaTests(TestCase):
                    '.requests') as requests_mock:
             requests_mock.post.return_value.json.return_value = {
                 'status': 'okay',
-                'email': 'persona@mail.com'
+                'email': 'persona@example.com'
             }
+
             resp = self.client.post(reverse('persona_login'),
                                     dict(assertion='dummy'))
-            self.assertEqual('http://testserver/accounts/profile/',
-                             resp['location'])
-            get_user_model().objects.get(email='persona@mail.com')
+            self.assertRedirects(resp, '/accounts/profile/',
+                                 fetch_redirect_response=False)
+            get_user_model().objects.get(email='persona@example.com')
