@@ -1,10 +1,12 @@
-from allauth.socialaccount.tests import create_oauth2_tests
-from allauth.tests import MockedResponse
-from allauth.socialaccount.providers import registry
+from allauth.socialaccount.tests import OAuth2TestsMixin
+from allauth.tests import MockedResponse, TestCase
 
 from .provider import SoundCloudProvider
 
-class SoundCloudTests(create_oauth2_tests(registry.by_id(SoundCloudProvider.id))):
+
+class SoundCloudTests(OAuth2TestsMixin, TestCase):
+    provider_id = SoundCloudProvider.id
+
     def get_mocked_response(self):
         return MockedResponse(200, """
         {
@@ -31,6 +33,7 @@ class SoundCloudTests(create_oauth2_tests(registry.by_id(SoundCloudProvider.id))
             "permalink": "user187631676",
             "country": null,
             "uri": "https://api.soundcloud.com/users/22341947",
-            "avatar_url": "https://a1.sndcdn.com/images/default_avatar_large.png?4b4189b",
+            "avatar_url":
+            "https://a1.sndcdn.com/images/default_avatar_large.png?4b4189b",
             "plan": "Free"
         }""")
