@@ -1,7 +1,6 @@
-from allauth.socialaccount import providers
+from allauth.socialaccount import app_settings
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
-from allauth.socialaccount import app_settings
 
 
 class SpotifyAccount(ProviderAccount):
@@ -11,7 +10,6 @@ class SpotifyAccount(ProviderAccount):
 class SpotifyOAuth2Provider(OAuth2Provider):
     id = 'spotify'
     name = 'Spotify'
-    package = 'allauth.socialaccount.providers.spotify'
     account_class = SpotifyAccount
 
     def extract_uid(self, data):
@@ -27,4 +25,5 @@ class SpotifyOAuth2Provider(OAuth2Provider):
             scope.append('user-read-email')
         return scope
 
-providers.registry.register(SpotifyOAuth2Provider)
+
+provider_classes = [SpotifyOAuth2Provider]
