@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-from allauth.socialaccount.tests import create_oauth2_tests
-from allauth.tests import MockedResponse
-from allauth.socialaccount.providers import registry
+from allauth.socialaccount.tests import OAuth2TestsMixin
+from allauth.tests import MockedResponse, TestCase
 
 from .provider import SpotifyOAuth2Provider
 
 
-class SpotifyOAuth2Tests(create_oauth2_tests(registry.by_id(
-        SpotifyOAuth2Provider.id))):
+class SpotifyOAuth2Tests(OAuth2TestsMixin, TestCase):
+    provider_id = SpotifyOAuth2Provider.id
+
     def get_mocked_response(self):
         return MockedResponse(200, """{
           "birthdate": "1937-06-01",
@@ -28,11 +28,12 @@ class SpotifyOAuth2Tests(create_oauth2_tests(registry.by_id(
           "images": [
             {
               "height": null,
-              "url": "https://fbcdn-profile-a.akamaihd.net/hprofile-ak-frc3/t1.0-1/1970403_10152215092574354_1798272330_n.jpg",
+              "url":
+              "https://fbcdn-profile-a.akamaihd.net/hprofile-ak-frc3/t1.0-1/1970403_10152215092574354_1798272330_n.jpg",
               "width": null
             }
           ],
           "product": "premium",
           "type": "user",
           "uri": "spotify:user:wizzler"
-        }""")
+        }""")  # noqa
