@@ -1,9 +1,12 @@
 import json
 
 from allauth.socialaccount.providers.oauth.client import OAuth
-from allauth.socialaccount.providers.oauth.views import (OAuthAdapter,
-                                                         OAuthLoginView,
-                                                         OAuthCallbackView)
+from allauth.socialaccount.providers.oauth.views import (
+    OAuthAdapter,
+    OAuthCallbackView,
+    OAuthLoginView,
+)
+
 from .provider import VimeoProvider
 
 
