@@ -1,26 +1,30 @@
 from django.contrib import messages
-from django.http import HttpResponseRedirect
-from django.core.urlresolvers import reverse, reverse_lazy
 from django.contrib.auth.decorators import login_required
+from django.contrib.sites.shortcuts import get_current_site
+from django.http import HttpResponseRedirect
+from django.urls import reverse, reverse_lazy
 from django.views.generic.base import TemplateView
 from django.views.generic.edit import FormView
 
-from ..account.views import (CloseableSignupMixin,
-                             RedirectAuthenticatedUserMixin)
+from . import app_settings, helpers
+from ..account import app_settings as account_settings
 from ..account.adapter import get_adapter as get_account_adapter
-from ..utils import get_form_class, get_current_site
-
+from ..account.views import (
+    AjaxCapableProcessFormViewMixin,
+    CloseableSignupMixin,
+    RedirectAuthenticatedUserMixin,
+)
+from ..utils import get_form_class
 from .adapter import get_adapter
-from .models import SocialLogin
 from .forms import DisconnectForm, SignupForm
-from . import helpers
-from . import app_settings
+from .models import SocialAccount, SocialLogin
 
 
 class SignupView(RedirectAuthenticatedUserMixin, CloseableSignupMixin,
-                 FormView):
+                 AjaxCapableProcessFormViewMixin, FormView):
     form_class = SignupForm
-    template_name = 'socialaccount/signup.html'
+    template_name = (
+        'socialaccount/signup.' + account_settings.TEMPLATE_EXTENSION)
 
     def get_form_class(self):
         return get_form_class(app_settings.FORMS,
@@ -37,8 +41,9 @@ class SignupView(RedirectAuthenticatedUserMixin, CloseableSignupMixin,
         return super(SignupView, self).dispatch(request, *args, **kwargs)
 
     def is_open(self):
-        return get_adapter().is_open_for_signup(self.request,
-                                                self.sociallogin)
+        return get_adapter(self.request).is_open_for_signup(
+            self.request,
+            self.sociallogin)
 
     def get_form_kwargs(self):
         ret = super(SignupView, self).get_form_kwargs()
@@ -59,24 +64,31 @@ class SignupView(RedirectAuthenticatedUserMixin, CloseableSignupMixin,
     def get_authenticated_redirect_url(self):
         return reverse(connections)
 
+
 signup = SignupView.as_view()
 
 
 class LoginCancelledView(TemplateView):
-    template_name = "socialaccount/login_cancelled.html"
+    template_name = (
+        "socialaccount/login_cancelled." + account_settings.TEMPLATE_EXTENSION)
+
 
 login_cancelled = LoginCancelledView.as_view()
 
 
 class LoginErrorView(TemplateView):
-    template_name = "socialaccount/authentication_error.html"
+    template_name = (
+        "socialaccount/authentication_error." +
+        account_settings.TEMPLATE_EXTENSION)
 
 
 login_error = LoginErrorView.as_view()
 
 
-class ConnectionsView(FormView):
-    template_name = "socialaccount/connections.html"
+class ConnectionsView(AjaxCapableProcessFormViewMixin, FormView):
+    template_name = (
+        "socialaccount/connections." +
+        account_settings.TEMPLATE_EXTENSION)
     form_class = DisconnectForm
     success_url = reverse_lazy("socialaccount_connections")
 
@@ -98,4 +110,18 @@ class ConnectionsView(FormView):
         form.save()
         return super(ConnectionsView, self).form_valid(form)
 
+    def get_ajax_data(self):
+        account_data = []
+        for account in SocialAccount.objects.filter(user=self.request.user):
+            provider_account = account.get_provider_account()
+            account_data.append({
+                'id': account.pk,
+                'provider': account.provider,
+                'name': provider_account.to_str()
+            })
+        return {
+            'socialaccounts': account_data
+        }
+
+
 connections = login_required(ConnectionsView.as_view())
